@@ -19,7 +19,7 @@ my %_RENAME_FOR = ( 'Description' => 'desc',
 
 #---HELPER FUNCTION---
 # Purpose: Map JSON package info keys to their new names...
-sub _rpc_pretty_pkginfo
+sub _munge_result
 {
     my ($info_ref) = @_;
 
@@ -50,11 +50,33 @@ sub info
     my $data = $json->decode( $resp->content );
 
     if ( $data->{type} eq "error" ) {
-        return undef if $data->{results} eq 'No results found';
+        return () if $data->{results} eq 'No results found';
         Carp::croak "Remote error: $data->{results}";
     }
 
-    return %{ _rpc_pretty_pkginfo( $data->{results} ) };
+    return %{ _munge_result( $data->{results} ) };
+}
+
+sub multiinfo
+{
+    my (@names) = @_;
+
+    my $uri     = rpc_uri( "multiinfo", @names );
+    my $ua      = WWW::AUR::UserAgent->new;
+    my $resp    = $ua->get( $uri );
+
+    Carp::croak 'Failed to call multiinfo AUR RPC: ' . $resp->status_line
+        unless $resp->is_success;
+
+    my $json = JSON->new;
+    my $data = $json->decode( $resp->content );
+
+    if ( $data->{type} eq "error" ) {
+        return () if $data->{results} eq 'No results found';
+        Carp::croak "Remote error: $data->{results}";
+    }
+
+    return map { _munge_result($_) } @{$data->{results}};
 }
 
 sub search
@@ -87,12 +109,12 @@ sub search
         Carp::croak "Remote error: $data->{results}";
     }
 
-    my $results = [ map { _rpc_pretty_pkginfo( $_ ) } @{ $data->{results} } ];
+    my $results = [ map { _munge_result( $_ ) } @{ $data->{results} } ];
 
     if ( $regexp ) {
         $results = [ grep { $_->{name} =~ /$regexp/ } @$results ];
     }
-    
+
     return $results;
 }
 
@@ -111,10 +133,10 @@ sub msearch
 
     if ( $json_ref->{type} eq 'error' ) {
         return [] if $json_ref->{results} eq 'No results found';
-        Carp::croak "Remote error: $json_ref->{results}";        
+        Carp::croak "Remote error: $json_ref->{results}";
     }
 
-    return [ map { _rpc_pretty_pkginfo( $_ ) } @{ $json_ref->{results} } ];
+    return [ map { _munge_result( $_ ) } @{ $json_ref->{results} } ];
 }
 
 1;
